#import "template.typ": *

#set page(
  paper: "a6",
  margin: (x: 0.8cm, y: 0.8cm),
)
#set text(
  font: "MonaspiceNe NF",
  size: 4pt,
  fill: bodyColour
)
#set par(
  justify: true,
  leading: 0.52em,
)

#chunk((
  align(center)[
    #text(size: 10pt, weight: "bold", fill: textDarkOrange)[NICK HIEBERT]
  ],
  align(center)[
    #grid(
      columns: (auto, auto, auto),
      gutter: 1em,
      align: horizon,
      contact(
        prefix: "tel:",
        entry: "12049986746",
        display: "1-204-998-6746",
        icon: "assets/phone.svg"
      ),
      contact(
        prefix: "mailto:",
        entry: "nick@upRootNutrition.com",
        display: "nick@upRootNutrition.com",
        icon: "assets/email.svg"
      ),
      contact(
        prefix: "",
        entry: "https://gitlab.com/upRootNutrition",
        display: "gitlab.com/upRootNutrition",
        icon: "assets/gitlab.svg"
      )
    )
  ],
  divider("ABOUT ME"),
  text("I am a former student of the University of Manitoba, having studied Human Nutritional Science. Nutrition is my foremost passion, though I have acquired a diverse range of skills and interests over the years that I pursue with persistence and enthusiasm. I discovered a love for programming when I switched from Windows to NixOS, an operating system that must be configured with the purely functional programming language, Nix. I have since taught myself Elm and Typst, and am currently working to gain proficiency with Haskell."),
  divider("EXPERIENCE"),
  job(
      company: "upRootNutrition",
      title: "Content Creator, Programmer",
      dates: "2018 - Present",
      location: "Winnipeg, MB",
      details: (
        "Developed evidence-based content related to nutrition science.",
        "Conducted in-depth investigations into nutrition science for clients.",
        "Mentored clients on research methodologies and interpretation."
      )
    ),
  divider("PROJECTS"),
  project(
    title: "upRootNutrition",
    entry: "https://source.uprootnutrition.com/upRootNutrition/website",
    lines: "35,650",
    position: "Lead Developer",
    date: "2024 - Present",
    lang: (
      "assets/elm.svg",
      "assets/typescript.svg",
      "assets/html.svg",
      "assets/css.svg",
      "assets/nix.svg",
      "assets/markdown.svg"
    ),
    description: "Developed upRootNutrition as the frontend for my online platform, primarily written in the Elm programming language, but also features Javascript, CSS, and HTML. modular configuration for pages, styling, and data handling. Organized records and helper functions for blog posts, debates, services, and donations. Designed reusable components like Markdown parsing, responsive elements, centralized style management. The project also makes use of Nix Devshells to create a declarative and reproducible development environment."
  ),
  project(
    title: "NixOS Dotfiles",
    entry: "https://source.uprootnutrition.com/upRootNutrition/dotfiles",
    lines: "20,903",
    position: "Lead Developer",
    date: "2022 - Present",
    lang: (
      "assets/nix.svg",
      "assets/bash.svg",
      "assets/css.svg",
      "assets/markdown.svg",
    ),
    description: "Developed a modular, multi-system NixOS configuration using flakes. Designed helper functions to streamline system and user setups, which makes adding and removing systems trivial. There are structured and expandable modules for machines, services, theming, user profiles, as well as declarative home management with Home Manager. Secrets are securely managed via sops-nix and a hardware dongle for private keys. Included in the flake are also project templates for quick bootstrapping in languages like Haskell and Elm."
  ),
  project(
    title: "This Resume",
    entry: "https://source.uprootnutrition.com/upRootNutrition/resume",
    position: "Lead Developer",
    date: "2025 - Present",
    lang: (
      "assets/typst.png",
      "assets/nix.svg"
    ),
    description: "Developed a customizable resume template using Typst, a modern markup-based typesetting system with some functional programming features and encourages immutable state. The project features modular components for sections like education, work experience, and projects, with flexible styling options. The project is built with a Nix devshell for a reproducible development environment.",
  ),
  project(
    title: "Homelab",
    entry: "https://source.uprootnutrition.com/upRootNutrition/dotfiles/src/branch/main/modules/nixos/services",
    lines: "35,650",
    position: "Lead Developer",
    date: "2023 - Present",
    lang: (
      "assets/nix.svg",
    ),
    description: [
          Developed a NixOS-based homelab for managing and hosting multiple services, such as
          #link("https://github.com/dani-garcia/vaultwarden", text(fill: linkColour)[Vaultwarden]),
          #link("https://codeberg.org/forgejo/forgejo", text(fill: linkColour)[Forgejo]),
          #link("https://github.com/nextcloud/server", text(fill: linkColour)[Nextcloud]),
          #link("https://github.com/jellyfin/jellyfin", text(fill: linkColour)[Jellyfin]),
          #link("https://github.com/searxng/searxng", text(fill: linkColour)[SearXNG]),
          #link("https://github.com/ollama/ollama", text(fill: linkColour)[Ollama]), as well as the
          #link("https://uprootnutrition.com/", text(fill: linkColour)[upRootNutrition website]). The Nix configuration features automated SSL certification generation for HTTPS, and hosts services to the internet from the Caddy webserver for reverse proxy. Currently the homelab is a Ryzen 5 system with 32GB of ram and 12TB of NAS storage.
        ]
  ),
  divider("PUBLICATIONS"),
  pub(
    author: "Moore, Jeff M., et al.",
    doi: "doi.org/10.1093/cdn/nzac043",
    entry: "https://doi.org/10.1093/cdn/nzac043",
    title: "‘Evidence for a Lean Mass Hyperresponder Phenotype Is Lacking with Increases in LDL Cholesterol of Clinical Significance in All Categories of Response to A-Restricted Diet’. Current Developments in Nutrition, vol. 6, no. 5, May 2022, p. nzac043."
  ),
  divider("EDUCATION"),
  list((
    edu(
      institute: "University of Manitoba",
      cert: "Human Nutritional Science",
      year: "2011"
    ),
    edu(
      institute: "Studio 11 Inc",
      cert: "Audio Production",
      year: "2008"
    )
  ))
))
