#let textLightGrey = rgb("#D4D4D4")
#let textDarkGrey = rgb("#7E7E7E")
#let textLightOrange = rgb("#CC6600")
#let textDarkOrange = rgb("#783C00")
#let textDeepDarkOrange = rgb("#3C1E00")
#let backgroundLightGrey = rgb("#282828")
#let backgroundDarkGrey = rgb("#1E1E1E")
#let backgroundDeepDarkGrey = rgb("#141414")
#let shadow = rgb("#0A0A0A")
#let barGreen = rgb("#006600")
#let barRed = rgb("#660000")
#let debugColour = rgb("#E31C79")

#let chunk(content) = {
  stack(
    spacing: 1em,
    ..content
  )
}

#let list(content) = {
  stack(
    spacing: 0.75em,
    ..content
  )
}

#let titlesize = 5pt

#let titleColour = textDarkOrange
#let subTitleColour = textDeepDarkOrange
#let bodyColour = backgroundLightGrey
#let linkColour = textLightOrange

#let contact(prefix: "", entry: "", display: "", icon: "") = {
  let url = prefix + entry
    grid(
      columns: (auto, auto),
      gutter: 0.2em,
      image(icon, height: 1em),
      link(url)[#text(fill: textLightOrange)[#display]]
    )
}

#let divider(title) = {
  pad(y: 0.2em)[
      #grid(
        columns: (1fr, auto, 1fr),
        column-gutter: 1em,
        align: (horizon, horizon, horizon),
        curve(
          stroke: (paint: gradient.linear(textLightOrange, textDarkOrange), thickness: 0.5pt),
          curve.move((0%, 0%)),
          curve.line((40%, 0%)),
          // curve.cubic((44%, 2%), (48%, -2%), (55%, 0%)),
          curve.line((100%, 0%))
        ),
        text(size: 9pt, weight: "bold", fill: titleColour)[#title],
        curve(
          stroke: (paint: gradient.linear(textDarkOrange, textLightOrange), thickness: 0.5pt),
          curve.move((100%, 0%)),
          curve.line((60%, 0%)),
          // curve.cubic((55%, -2%) (52%, 2%), (45%, 0%)),
          curve.line((0%, 0%))
        )
      )
    ]
  }
#let job(
  company: "",
  title: "",
  dates: "",
  location: "",
  details: ()
) = {
  block(spacing: 0.75em)[
    #stack(
      spacing: 0.75em,
      [#text(weight: "bold", size: titlesize, fill: titleColour)[#company]],
      [
        #grid(
          columns: (1fr, auto),
          align(left)[#text(style: "italic", fill: textLightOrange)[#title]],
          align(right)[#text(fill: textLightOrange)[#dates]]
        )
      ],
      [
        #pad(left: 1.5em)[
          #list(details.map(detail => [• #detail]))
        ]
      ]
    )
  ]
}

#let project(
  title: "",
  position: "",
  entry: "",
  lines: "",
  date: "",
  description: "",
  lang: (),
) = {
  block(spacing: 0.75em)[
    #stack(
      spacing: 0.75em,
      [#grid(
        columns: (1fr, auto),
        align: (bottom, bottom),
        link(entry)[#text(weight: "bold", size: titlesize, fill: titleColour)[#title]],
        box(grid(
          columns: (auto,) * lang.len(),
          align: (right,) * lang.len(),
          gutter: 2pt,
          ..lang.map(icon => image(icon, height: 2em))
        )
        ),
        )],
      [#grid(
        columns: (1fr, auto),
        align: (bottom + left, bottom + right),
        [#text(style: "italic", fill: textLightOrange)[#position]],
        [#text(style: "italic", fill: textLightOrange)[#date]]
      )
      ],
      [#text()[#description]]
    )
  ]
}

#let edu(
  institute: "",
  cert: "",
  year: ""
) = {
  block(spacing: 0.75em)[
    #stack(
    spacing: 0.75em,
    [
      #text(weight: "bold",size: titlesize, fill: titleColour)[#institute]
    ],
    [
      #grid(
        columns: (1fr, auto),
        text(fill: textLightOrange)[#cert],
        text(style: "italic", fill: textLightOrange)[#year]
      )
    ]
    )
  ]
}

#let pub(
  author: "",
  entry: "",
  doi: "",
  title: ""
) = {
  block(spacing: 0.75em)[
    #stack(
      spacing: 0.75em,
      [
        #text(weight: "bold",size: titlesize, fill: titleColour)[#author]
        #text(style: "italic", fill: backgroundLightGrey)[#title]
      ],
      [
        #link(entry)[#text(fill: textLightOrange)[#doi]]
      ]
    )
  ]
}
